hepstats.utils.fit package
==========================

.. automodule:: hepstats.utils.fit
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:

Submodules
----------

.. toctree::
   :maxdepth: 4

   hepstats.utils.fit.api_check
   hepstats.utils.fit.diverse
   hepstats.utils.fit.sampling
